OC.L10N.register(
    "sip_trip_phone",
    {
    "Settings" : "Settings",
    "SIP Trip Phone" : "SIP Trip Phone",
    "Please enter your credentials in the fields from below:" : "Please enter your credentials in the fields from below:",
    "Display Name: *" : "Display Name: *",
    "e.g. Ben Dove" : "e.g. Ben Dove",
    "SIP User: *" : "SIP User: *",
    "e.g. 1610  or john_doe" : "e.g. 1610  or john_doe",
    "SIP User Password: *" : "SIP User Password: *",
    "e.g. r?2V!s5w9Q&d7W?8" : "e.g. r?2V!s5w9Q&d7W?8",
    "WSS URL: *" : "WSS URL: *",
    "e.g. wss://cloud.example.com:8089/ws" : "e.g. wss://cloud.example.com:8089/ws",
    "SIP Realm  (the public IPv4 of your Asterisk server): *" : "SIP Realm  (the public IPv4 of your Asterisk server): *",
    "e.g. 123.123.123.123" : "e.g. 123.123.123.123",
    "STUN Server domain or IPv4 address, and port number:" : "STUN Server domain or IPv4 address, and port number:",
    "e.g. 123.123.123.123:8443" : "e.g. 123.123.123.123:8443",
    "Save" : "Save"
},
"nplurals=2; plural=(n != 1);");
